@@ -2,6 +2,7 @@
 # from pprint import pprint
 import argparse
 import shutil
+import traceback
 from pyfiglet import Figlet
 from PyInquirer import prompt
 
@@ -11,24 +12,18 @@ from flask_sketch.questions import get_questions
 
 parser = argparse.ArgumentParser(description="Flask Sketch CLI")
 parser.add_argument("project_name", type=str)
+parser.add_argument("-e", action="store_true", help="Create examples endpoints")
 parser.add_argument(
-    "-e", action="store_true", help="Create examples endpoints"
+    "-p", action="store_true", help="Create a pyproject.toml to work with poetry",
 )
 parser.add_argument(
-    "-p",
-    action="store_true",
-    help="Create a pyproject.toml to work with poetry",
-)
-parser.add_argument(
-    "-v",
-    action="store_true",
-    help="Create a virtualenv and install requirements",
+    "-v", action="store_true", help="Create a virtualenv.",
 )
 
 f = Figlet(font="slant")
 
 
-def flask_sketch(args):
+def main(args):
     print(f.renderText("Flask Sketch"))
 
     answers = prompt(get_questions(), style=cli_style_2)
@@ -36,13 +31,22 @@ def flask_sketch(args):
         create_project(args, answers)
 
 
-if __name__ == "__main__":
-
+def flask_sketch():
     args = parser.parse_args()
     args.project_name = args.project_name.lower()
     try:
-        flask_sketch(args)
+        main(args)
+    except FileExistsError as e:
+        print("\n\nAn error occurred during generating files:")
+        print(e)
+        tb = traceback.format_exc()
     except Exception as e:
         print("\n\nAn error occurred during generating files:")
         print(e)
         shutil.rmtree(args.project_name)
+        tb = traceback.format_exc()
+    else:
+        tb = None
+    finally:
+        if tb:
+            print("\n\n", tb)
